@@ -48,6 +48,7 @@ func providerImporterSubcommands() []func(options ImportOptions) *cobra.Command
 		newCmdDigitalOceanImporter,
 		newCmdEquinixMetalImporter,
 		newCmdHerokuImporter,
+		newCmdLaunchDarklyImporter,
 		newCmdLinodeImporter,
 		newCmdOpenStackImporter,
 		newCmdTencentCloudImporter,
@@ -69,8 +70,10 @@ func providerImporterSubcommands() []func(options ImportOptions) *cobra.Command
 		// Monitoring & System Management
 		newCmdDatadogImporter,
 		newCmdNewRelicImporter,
+		newCmdMackerelImporter,
 		newCmdGrafanaImporter,
 		newCmdPagerDutyImporter,
+		newCmdOpsgenieImporter,
 		// Community
 		newCmdKeycloakImporter,
 		newCmdLogzioImporter,
@@ -80,6 +83,7 @@ func providerImporterSubcommands() []func(options ImportOptions) *cobra.Command
 		newCmdGmailfilterImporter,
 		newCmdVaultImporter,
 		newCmdOktaImporter,
+		newCmdAuth0Importer,
 	}
 }
 
@@ -97,6 +101,7 @@ func providerGenerators() map[string]func() terraformutils.ProviderGenerator {
 		newEquinixMetalProvider,
 		newFastlyProvider,
 		newHerokuProvider,
+		newLaunchDarklyProvider,
 		newLinodeProvider,
 		newNs1Provider,
 		newOpenStackProvider,
@@ -125,6 +130,7 @@ func providerGenerators() map[string]func() terraformutils.ProviderGenerator {
 		newGmailfilterProvider,
 		newVaultProvider,
 		newOktaProvider,
+		newAuth0Provider,
 	} {
 		list[providerGen().GetName()] = providerGen
 	}
