@@ -16,10 +16,14 @@ package ibm
 
 import (
 	"errors"
+	"os"
 
 	"github.com/GoogleCloudPlatform/terraformer/terraformutils"
 )
 
+const DefaultRegion = "us-south"
+const NoRegion = ""
+
 type IBMProvider struct { //nolint
 	terraformutils.Provider
 	ResourceGroup string
@@ -32,6 +36,16 @@ func (p *IBMProvider) Init(args []string) error {
 	p.Region = args[1]
 	p.CIS = args[2]
 
+	var err error
+	if p.Region != DefaultRegion && p.Region != NoRegion {
+		err = os.Setenv("IC_REGION", p.Region)
+	} else {
+		p.Region = DefaultRegion
+		err = os.Setenv("IC_REGION", DefaultRegion)
+	}
+	if err != nil {
+		return err
+	}
 	return nil
 }
 
@@ -42,7 +56,9 @@ func (p *IBMProvider) GetName() string {
 func (p *IBMProvider) GetProviderData(arg ...string) map[string]interface{} {
 	return map[string]interface{}{
 		"provider": map[string]interface{}{
-			"ibm": map[string]interface{}{},
+			"ibm": map[string]interface{}{
+				"region": p.Region,
+			},
 		},
 	}
 }
@@ -88,6 +104,7 @@ func (p *IBMProvider) GetSupportedService() map[string]terraformutils.ServiceGen
 		"ibm_direct_link":            &DLGenerator{},
 		"ibm_transit_gateway":        &TGGenerator{},
 		"ibm_vpe_gateway":            &VPEGenerator{},
+		"ibm_satellite":              &SatelliteGenerator{},
 	}
 }
 
